###################################################
# This script splices all intervals with user-specified labels on a user-specified tier from all sounds in a directory
# and saves them in a new directory, with or without the corresponding TG files.
#
# All labels to be spliced should be listed in a text file with one label per line.
#
# Filenames will be saved in the format: <label>_<long_filename>.wav
# If there are multiple versions of each label for a given file, this will overwrite and only save the last one.
# To avoid this, set includeTime = 1, and the filename will be of the format <label>_<long_filename>_<time>.wav.
# Time is rounded to the nearest integer.
#
# jessamyn.schertz@gmail.com 
# November 30, 2015
#
###################################################

beginPause: "User input"
	word: "dataDir", "original_data/"
	word: "outDir", "spliced_data/"
	boolean: "spliceTG", 1
	comment: "Text file with labels to be spliced:"
	word: "wordsToChop", "words_to_chop.txt"
	comment: "Tier number of the relevant labels:"
	positive: "labelTier", 2
	comment: "Click to include the time as part of the (new) filename"
	boolean: "includeTime", 1
	comment: "Spliced files will include this duration of buffer on either side of the boundary (s)"
	real: "buffer", 0.02
endPause: "Continue", 1

select all
nocheck Remove

wordList = Read Strings from raw text file: wordsToChop$
Sort
wordList = To WordList

fileList = Create Strings as file list: "", dataDir$+"*.TextGrid"
numFiles = Get number of strings
for file from 1 to numFiles
	select fileList
	filename$ = Get string: file
	filename$ = filename$-".TextGrid"
	ls = Open long sound file: dataDir$+filename$+".wav"
	tg = Read from file: dataDir$+filename$+".TextGrid"
	numInt = Get number of intervals: labelTier

	for int from 1 to numInt
		select tg
		flag = 0
		label$ = Get label of interval: labelTier, int
		select wordList
		inWordList = Has word: label$
		if inWordList == 1
			call splice
		endif
	endfor
	select tg
	plus ls
	Remove
endfor

procedure splice
	select tg
	start = Get start point: labelTier, int
	end = Get end point: labelTier, int
	newFilename$=label$+"_"+filename$
	if includeTime == 1
		time = round(start)
		newFilename$ = label$+"_"+filename$+"_"+"'time'"
	endif
	select ls
	soundPart = Extract part: start-buffer, end+buffer, "no"
	Save as WAV file: outDir$+newFilename$+".wav"
	if spliceTG == 1
		call write_tg
	endif
	select soundPart
	Remove
endproc

procedure write_tg
	select tg
	tgPart = Extract part: start-buffer, end+buffer, "no"
	Save as text file: outDir$+newFilename$+".TextGrid"
	Remove
endproc









